from setuptools import setup, find_packages

setup(
    name='flyers',
    version='0.0.3',
    author='pushyzheng',
    author_email='1437876073@qq.com',
    url='https://github.com/pushyzheng',
    description=u'A collections of utils',
    packages=['flyers'],
    install_requires=find_packages()
)
